# TruckersFM.py

Simple API wrapper for TruckersFM, the popular simulating radio station.

# Table of contents
- [Installation and setup](https://github.com/supraaxdd/TruckersMP.py/#installation-and-setup)
- [Usage](https://github.com/supraaxdd/TruckersMP.py/#usage)
- [Support](https://github.com/supraaxdd/TruckersMP.py/#support)
- [Contributing](https://github.com/supraaxdd/TruckersMP.py/#contributing)
- [Acknowledgements](https://github.com/supraaxdd/TruckersMP.py/#acknowledgements)

## Installation and setup

**This module is compatible with Python v3+**

You can install this module via github or PyPI:
```bash
$ pip install git+https://github.com/supraaxdd/TruckersMP.py.git
```

```bash
$ pip install TruckersMP.py
```